@@ -35,8 +35,8 @@ def send_notifications(email, sender, email_configuration):
         email_us=email_configuration.get('Email_Us'),
         faq_url=email_configuration.get('FAQ_URL'),
         unsubscribe=email_configuration.get('Unsubscribe_Email_ID'),
-        banner=email_configuration.get('Banner'))
-    # banner="http://localhost:8000/" + email_configuration.Banner.url)
+        banner="http://localhost:8000/media/" +
+               email_configuration.get('Banner'))
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
 
@@ -54,7 +54,6 @@ def send_notifications(email, sender, email_configuration):
             mail.content_subtype = "html"
             # Add the attachment to the parent container.
             mail.attach(att)
-
             mail.send()
             logging.FileHandler(getattr(settings, "LOG_PATH", None),
                                 mode='w')
@@ -85,7 +84,8 @@ def send_notifications_with_msg(email, sender, msg, email_configuration):
         email_us=email_configuration.get('Email_Us'),
         faq_url=email_configuration.get('FAQ_URL'),
         unsubscribe=email_configuration.get('Unsubscribe_Email_ID'),
-        banner=email_configuration.get('Banner'))
+        banner="https://xds-admin.deloitteopenlxp.com/media/" +
+               email_configuration.get('Banner'))
 
     for each_recipient in RECIPIENT:
         try:
